#include "main.h"


int main(int argc, char *argv[])
{
	check_drivers();
	hci_up();
	num_rsp=0;
	selected=0;
	if(SDL_Init(SDL_INIT_AUDIO|SDL_INIT_VIDEO|SDL_INIT_JOYSTICK) < 0) {
		fprintf(stderr, "SDL Init failed: %s\n", SDL_GetError());
		exit(1);
	}
	SDL_JoystickOpen(0);
	atexit(SDL_Quit);
	screen=SDL_SetVideoMode(320,240,16,SDL_SWSURFACE);
	SDL_ShowCursor(0);

	if(screen==NULL) {
		fprintf(stderr, "Can't set video mode: %s\n",SDL_GetError());
		exit(1);	
	}
	image=IMG_Load("./ressources/splash_bt2x.png");
	if(image==NULL) {
		fprintf(stderr, "Can't load splash image: %s\n",SDL_GetError());
		exit(1);
	}
	dest.x=0;
	dest.y=0;
	dest.w=image->w;
	dest.h=image->h;
	SDL_BlitSurface(image,NULL,screen,&dest);
	SDL_UpdateRects(screen,1,&dest);

	if(TTF_Init()<0) {
		fprintf(stderr, "TTF_Init Failed: %s\n",SDL_GetError());
		exit(1);
	}
	police=TTF_OpenFont("./ressources/font.ttf",16);
	if(!police) {
		fprintf(stderr, "Can't open the TTF font file: %s\n",SDL_GetError());
		exit(1);
	}
	SDL_Delay(2000);
	MainScreen();
}

void MainScreen() {
	bg=IMG_Load("./ressources/main_screen.png");
	if(bg==NULL) {
		fprintf(stderr,"Can't load the main png image: %s\n",SDL_GetError());
		exit(1);
	}
	SDL_BlitSurface(bg,NULL,screen,&dest);
	SDL_UpdateRects(screen,1,&dest);
	while(1) {
		SDL_WaitEvent(&event);
		if(event.type==GP2X_BUTTON_EVENT) {
			switch (GP2X_BUTTON_ID) {
				case GP2X_BUTTON_START:
					exit(0);
					break;
				case GP2X_BUTTON_Y:
					ScanBt();
					break;
				case GP2X_BUTTON_DOWN:
					SelDown(selected+1);
					break;
				case GP2X_BUTTON_UP:
					SelUp(selected-1);
					break;
			}		

		}
	}

}

void ScanBt() {
	printf ("Scan engaged\n");
	dest.x=0;
	dest.y=0;
	dest.w=bg->w;
	dest.h=bg->h;	
	SDL_BlitSurface(bg,NULL,screen,&dest);
	SDL_UpdateRects(screen,1,&dest);

	dev_id = 0;
	length = 8;
	num_rsp=10;
	flags=0;
		
	num_rsp=hci_inquiry(dev_id,length,num_rsp,NULL,&info,flags);
	for(i=0;i<num_rsp; i++) {
		baswap(&bdaddr, &(info+i)->bdaddr);
		dd=hci_open_dev(dev_id);
		if(hci_read_remote_name(dd,&(info+i)->bdaddr,40,buffer,100000)<0) {
			snprintf(buffer,40,"<n/a>");
		}
		hci_close_dev(dd);
		bluetooth[i].id=i;
		bluetooth[i].name=buffer;
		bluetooth[i].addr=(info+i)->bdaddr;
		AffResult(buffer,i);
		fprintf(stdout,"ID: %i Nom: %s\n",bluetooth[i].id,bluetooth[i].name);
	}
	fprintf(stdout,"Scan finished, %i devices responded\n",num_rsp);
	SelDown(0);
}

void AffResult(char* texte, int ligne) {
	
	image=TTF_RenderText_Solid(police,texte,couleur);
	dest.x=35;
	dest.y=69+(16*ligne);
	dest.w=image->w;
	dest.h=image->h;
	SDL_BlitSurface(image,NULL,screen,&dest);
	SDL_UpdateRects(screen,1,&dest);

}

void check_drivers() {
	dev_id=0;
	
	dd=hci_open_dev(dev_id);
	if(dd<0) {
		printf("Device not detected, loading modules\n");
		hci_close_dev(dd);
		system("/sbin/insmod ./modules/bluez.o");
		system("/sbin/insmod ./modules/l2cap.o");
		system("/sbin/insmod ./modules/hci_usb.o");
		system("/sbin/insmod ./modules/rfcomm.o");
	} else {
		printf("Driver already loaded\n");
		return;
	}
	dd=hci_open_dev(dev_id);
	if(dd<0) {
		hci_close_dev(dd);
		printf("Error, device not detected :(\n");
		exit(1);
	}
	printf("Ok, driver correct, device is working\n");
	hci_close_dev(dd);

}

void hci_up() {
	ctl=socket(AF_BLUETOOTH,SOCK_RAW,BTPROTO_HCI);
	if(ctl<0) {
		printf("Error, can't open HCI socket\n");
		exit(1);
	}
	dev_id=0;
	ioctl(ctl,HCIDEVUP,dev_id);
}

void SelDown(int ligne) {
	if (num_rsp==0) return;
	if (ligne==num_rsp) return;
	if(ligne>0) {
		selected++;
		image=IMG_Load("./ressources/unselect.png");
		if(image==NULL) {
			fprintf(stderr, "Can't load unselect image: %s\n",SDL_GetError());
			exit(1);
		}
		dest.x=20;
		dest.y=76+(16*(ligne-1));
		dest.w=image->w;
		dest.h=image->h;
		SDL_BlitSurface(image,NULL,screen,&dest);
		SDL_UpdateRects(screen,1,&dest);



	} else selected=0;
	image=IMG_Load("./ressources/select.png");
	if(image==NULL) {
		fprintf(stderr, "Can't load select image: %s\n",SDL_GetError());
		exit(1);
	}
	dest.x=20;
	dest.y=76+(16*ligne);
	dest.w=image->w;
	dest.h=image->h;
	SDL_BlitSurface(image,NULL,screen,&dest);
	SDL_UpdateRects(screen,1,&dest);
}

void SelUp(int ligne) {
	if(num_rsp==0) return;
	if(ligne<0) return;
	selected--;
	image=IMG_Load("./ressources/unselect.png");
	if(image==NULL) {
		fprintf(stderr, "Can't load unselect image: %s\n",SDL_GetError());
		exit(1);
	}
	dest.x=20;
	dest.y=76+(16*(ligne+1));
	dest.w=image->w;
	dest.h=image->h;
	SDL_BlitSurface(image,NULL,screen,&dest);
	SDL_UpdateRects(screen,1,&dest);

	image=IMG_Load("./ressources/select.png");
	if(image==NULL) {
		fprintf(stderr, "Can't load select image: %s\n",SDL_GetError());
		exit(1);
	}
	dest.x=20;
	dest.y=76+(16*ligne);
	dest.w=image->w;
	dest.h=image->h;
	SDL_BlitSurface(image,NULL,screen,&dest);
	SDL_UpdateRects(screen,1,&dest);

}
